//+------------------------------------------------------------------+
//|                                                 FPI-3 Symbol.mq4 |
//|                                 Copyright  2006, John F. Kutzer |
//|                                     jack@wellnessbeach.com |
//+------------------------------------------------------------------+
// Implementation if Michal Kreslik's FPI indicator for Metatrader 4 (MT4)
// Read more about the concept at the link below:
//  http://kreslik.com/forums/viewtopic.php?p=2185#2185
//
// Thanks to Michal for working on this idea, and providing the information!
//
// This implementation will only handle 3 symbol sets. 
// Enter the 3 Symbols as inputs.
// Enter Long or Short as appropriate for each symbol.
// The indicator adjusts automatically for a regular or mini account, so you don't need to enter
//  the symbols with the 'm' for mini accounts.
//
//=================================
// PeriodMinutes |
//    Values     | Description 
// ==============|=================
//        1      |  1 minute. 
//        5      |  5 minutes. 
//       15      | 15 minutes. 
//       30      | 30 minutes. 
//       60      |  1 hour. 
//      240      |  4 hour. 
//     1440      |    Daily. 
//    10080      |    Weekly. 
//    43200      |    Monthly. 
//=================================



#property  copyright "Copyright  2006, John F. Kutzer"
#property  link      "jack@wellnessbeach.com"
//---- indicator settings
#property  indicator_separate_window
#property  indicator_buffers 1
#property  indicator_color1  Blue
#property  indicator_color2  Red
#property  indicator_width1  2
#property  indicator_width2  2

//---- indicator parameters
extern string Symbol1="EURGBP";
extern string LS1="Long";
extern string Symbol2="EURJPY";
extern string LS2="Short";
extern string Symbol3="GBPJPY";
extern string LS3="Long";
extern int    SignalLen = 8;
extern int    PeriodMinutes= 15;

//---- indicator buffers
double     FPIbuffer[];
//double     FPI_MAbuffer[];
double     aVar=0;
double     bVar=0;
double     cVar=0;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- drawing settings
   SetIndexStyle(0,DRAW_LINE);
//   SetIndexStyle(1,DRAW_LINE);
//   SetIndexDrawBegin(1,SignalLen);
   IndicatorDigits(MarketInfo(Symbol(),MODE_DIGITS)+1);

//---- indicator buffers mapping
   SetIndexBuffer(0,FPIbuffer);
//   SetIndexBuffer(1,FPI_MAbuffer);
//---- name for DataWindow and indicator subwindow label
   IndicatorShortName("FPI-3 ("+LS1 +" "+ Symbol1+" - "+LS2  +" "+ Symbol2+" - "+ LS3  +" " +Symbol3+")");
   SetIndexLabel(0,"FPI-3");
//   SetIndexLabel(1,"Signal");
//---- initialization done
   return(0);
  }
//+------------------------------------------------------------------+
//| FPI for 3 Symbol Groups                         |
//+------------------------------------------------------------------+
int start()
  {
//---- Adjust Symbols for Mini or Regular accounts
   double lotsize;
   lotsize = MarketInfo(Symbol1,MODE_LOTSIZE);
   if(lotsize < 100000)
      {
      Symbol1 = StringConcatenate(Symbol1,"m");
      Symbol2 = StringConcatenate(Symbol2,"m");
      Symbol3 = StringConcatenate(Symbol3,"m");
      }
   int limit;
   int counted_bars=IndicatorCounted();
//---- last counted bar will be recounted
   if(counted_bars>0) counted_bars--;
      limit=Bars-counted_bars;
//---- adjust for Long or Short position
   for(int i=0; i<limit; i++)
      {
      if(LS1 == "Long") aVar =  iClose(Symbol1,PeriodMinutes,i);  
      else           aVar = 1.0/(iClose(Symbol1,PeriodMinutes,i)+ MathPow(10,-Digits)*MarketInfo(Symbol1,MODE_SPREAD));
      if(LS2 == "Long") bVar =  iClose(Symbol2,PeriodMinutes,i);  
      else           bVar = 1.0/(iClose(Symbol2,PeriodMinutes,i)+ MathPow(10,-Digits)*MarketInfo(Symbol2,MODE_SPREAD));
      if(LS3 == "Long") cVar =  iClose(Symbol3,PeriodMinutes,i);  
      else           cVar = 1.0/(iClose(Symbol3,PeriodMinutes,i)+ MathPow(10,-Digits)*MarketInfo(Symbol3,MODE_SPREAD));
     
      FPIbuffer[i] = (aVar*bVar*cVar);
      }
      if(FPIbuffer[0] > 1) 
         Alert("FPI High --> " + DoubleToStr(FPIbuffer[0],4));
      if(FPIbuffer[0] < 0.99905) 
         Alert("FPI Low --> " + DoubleToStr(FPIbuffer[0],4));

//      for(i=0; i<limit; i++)
//         FPI_MAbuffer[i]=iMAOnArray(FPIbuffer,Bars,SignalLen,PeriodMinutes,MODE_SMA,i);
//      if(FPIbuffer[0] < FPI_MAbuffer[0] && FPIbuffer[0] > FPIbuffer[1])
//         Alert("FPI Value ==> " + DoubleToStr(FPIbuffer[0],Digits));
//Alert("test--> " + DoubleToStr(iClose(Symbol1,PeriodMinutes,0),5)+"  == " + DoubleToStr(MathPow(10,-Digits)*MarketInfo(Symbol1,MODE_SPREAD),5)+" == " +DoubleToStr((iClose(Symbol1,PeriodMinutes,0)+ MathPow(10,-Digits)*MarketInfo(Symbol1,MODE_SPREAD)),5));
//---- done
   return(0);
  }
//+------------------------------------------------------------------+
 